==> kubernetes-model-autoscaling-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta2/MetricStatusBuilder.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class MetricStatusBuilder extends MetricStatusFluentImpl<MetricStatusBuilder> implements VisitableBuilder<MetricStatus,MetricStatusBuilder>{
  public MetricStatusBuilder() {
    this(false);
  }
  public MetricStatusBuilder(Boolean validationEnabled) {
    this(new MetricStatus(), validationEnabled);
  }
  public MetricStatusBuilder(MetricStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public MetricStatusBuilder(MetricStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new MetricStatus(), validationEnabled);
  }
  public MetricStatusBuilder(MetricStatusFluent<?> fluent,MetricStatus instance) {
    this(fluent, instance, false);
  }
  public MetricStatusBuilder(MetricStatusFluent<?> fluent,MetricStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withContainerResource(instance.getContainerResource());
      fluent.withExternal(instance.getExternal());
      fluent.withObject(instance.getObject());
      fluent.withPods(instance.getPods());
      fluent.withResource(instance.getResource());
      fluent.withType(instance.getType());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public MetricStatusBuilder(MetricStatus instance) {
    this(instance,false);
  }
  public MetricStatusBuilder(MetricStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withContainerResource(instance.getContainerResource());
      this.withExternal(instance.getExternal());
      this.withObject(instance.getObject());
      this.withPods(instance.getPods());
      this.withResource(instance.getResource());
      this.withType(instance.getType());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  MetricStatusFluent<?> fluent;
  Boolean validationEnabled;
  public MetricStatus build() {
    MetricStatus buildable = new MetricStatus(fluent.getContainerResource(),fluent.getExternal(),fluent.getObject(),fluent.getPods(),fluent.getResource(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> kubernetes-model-autoscaling-6.8.1-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta2/MetricStatusBuilder.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class MetricStatusBuilder extends MetricStatusFluent<MetricStatusBuilder> implements VisitableBuilder<MetricStatus,MetricStatusBuilder>{
  public MetricStatusBuilder() {
    this(false);
  }
  public MetricStatusBuilder(Boolean validationEnabled) {
    this(new MetricStatus(), validationEnabled);
  }
  public MetricStatusBuilder(MetricStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public MetricStatusBuilder(MetricStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new MetricStatus(), validationEnabled);
  }
  public MetricStatusBuilder(MetricStatusFluent<?> fluent,MetricStatus instance) {
    this(fluent, instance, false);
  }
  public MetricStatusBuilder(MetricStatusFluent<?> fluent,MetricStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new MetricStatus());

    if (instance != null) {
      fluent.withContainerResource(instance.getContainerResource());
      fluent.withExternal(instance.getExternal());
      fluent.withObject(instance.getObject());
      fluent.withPods(instance.getPods());
      fluent.withResource(instance.getResource());
      fluent.withType(instance.getType());
      fluent.withContainerResource(instance.getContainerResource());
      fluent.withExternal(instance.getExternal());
      fluent.withObject(instance.getObject());
      fluent.withPods(instance.getPods());
      fluent.withResource(instance.getResource());
      fluent.withType(instance.getType());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public MetricStatusBuilder(MetricStatus instance) {
    this(instance,false);
  }
  public MetricStatusBuilder(MetricStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new MetricStatus());

    if (instance != null) {
      this.withContainerResource(instance.getContainerResource());
      this.withExternal(instance.getExternal());
      this.withObject(instance.getObject());
      this.withPods(instance.getPods());
      this.withResource(instance.getResource());
      this.withType(instance.getType());
      this.withContainerResource(instance.getContainerResource());
      this.withExternal(instance.getExternal());
      this.withObject(instance.getObject());
      this.withPods(instance.getPods());
      this.withResource(instance.getResource());
      this.withType(instance.getType());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  MetricStatusFluent<?> fluent;
  Boolean validationEnabled;
  public MetricStatus build() {
    MetricStatus buildable = new MetricStatus(fluent.buildContainerResource(),fluent.buildExternal(),fluent.buildObject(),fluent.buildPods(),fluent.buildResource(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
